@@ -801,6 +801,34 @@ class CvmClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeReservedInstancesConfigInfos(self, request):
+        """This API is used to describe reserved instance (RI) offerings. Currently, RIs are only offered to beta users.
+
+        :param request: Request instance for DescribeReservedInstancesConfigInfos.
+        :type request: :class:`tencentcloud.cvm.v20170312.models.DescribeReservedInstancesConfigInfosRequest`
+        :rtype: :class:`tencentcloud.cvm.v20170312.models.DescribeReservedInstancesConfigInfosResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeReservedInstancesConfigInfos", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeReservedInstancesConfigInfosResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeReservedInstancesOfferings(self, request):
         """This API is used to describe Reserved Instance offerings that are available for purchase.
 
@@ -829,6 +857,34 @@ class CvmClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeSpotTypeConfig(self, request):
+        """This API is used to query spot instances that are available for purchase.
+
+        :param request: Request instance for DescribeSpotTypeConfig.
+        :type request: :class:`tencentcloud.cvm.v20170312.models.DescribeSpotTypeConfigRequest`
+        :rtype: :class:`tencentcloud.cvm.v20170312.models.DescribeSpotTypeConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeSpotTypeConfig", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeSpotTypeConfigResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeZoneInstanceConfigInfos(self, request):
         """This API is used to query the configurations of models in an availability zone.
 
@@ -1006,6 +1062,34 @@ class CvmClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def InquirePricePurchaseReservedInstancesOffering(self, request):
+        """This API is used to query the price of reserved instances. It only supports querying purchasable reserved instance offerings. Currently, RIs are only offered to beta users.
+
+        :param request: Request instance for InquirePricePurchaseReservedInstancesOffering.
+        :type request: :class:`tencentcloud.cvm.v20170312.models.InquirePricePurchaseReservedInstancesOfferingRequest`
+        :rtype: :class:`tencentcloud.cvm.v20170312.models.InquirePricePurchaseReservedInstancesOfferingResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("InquirePricePurchaseReservedInstancesOffering", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.InquirePricePurchaseReservedInstancesOfferingResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def InquiryPriceResetInstance(self, request):
         """This API is used to query the price for reinstalling an instance.
 
