@@ -586,7 +586,7 @@ class TcaplusdbClient(AbstractClient):
 
 
     def DescribeUinInWhitelist(self, request):
-        """This API is used to query whether the current user is in the whitelist and control whether the user can create TDR-type apps or tables.
+        """This API is used to query whether the current user is in the allowlist and control whether the user can create TDR-type apps or tables.
 
         :param request: Request instance for DescribeUinInWhitelist.
         :type request: :class:`tencentcloud.tcaplusdb.v20190823.models.DescribeUinInWhitelistRequest`
